<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hy" sourcelanguage="en">
<context>
    <name>Alert</name>
    <message>
        <source>Close (%1)</source>
        <translation>Փակել (%1)</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>Ամփոփել</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Ընդարձակել</translation>
    </message>
</context>
<context>
    <name>AlertLayer</name>
    <message>
        <source>Dismiss Alert</source>
        <translation>Վերացնել նախազգուշացումը</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
</context>
<context>
    <name>DailyProgress</name>
    <message numerus="yes">
        <source>%Ln word(s)</source>
        <translation>
            <numerusform>%Ln բառ</numerusform>
            <numerusform>%Ln բառ</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%Ln minute(s)</source>
        <translation>
            <numerusform>%Ln րոպե</numerusform>
            <numerusform>%Ln րոպե</numerusform>
        </translation>
    </message>
    <message>
        <source>0%</source>
        <translation>0%</translation>
    </message>
    <message numerus="yes">
        <source>%L1% of %Ln minute(s)</source>
        <translation>
            <numerusform>%Ln րոպեի %L1%-ը</numerusform>
            <numerusform>%Ln րոպեի %L1%-ը</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%L1% of %Ln word(s)</source>
        <translation>
            <numerusform>%Ln բառի %L1%-ը</numerusform>
            <numerusform>%Ln բառի %L1%-ը</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>DailyProgressDialog</name>
    <message>
        <source>Daily Progress</source>
        <translation>Օրական առաջընթաց</translation>
    </message>
    <message>
        <source>Longest streak</source>
        <translation>Ամենաերկար շերտը</translation>
    </message>
    <message>
        <source>Current streak</source>
        <translation>Ներկա շերտը</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation>
            <numerusform>%n օր</numerusform>
            <numerusform>%n օր</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 &amp;ndash; %2</source>
        <translation>%1 &amp;ndash; %2</translation>
    </message>
</context>
<context>
    <name>DailyProgressLabel</name>
    <message>
        <source>%L1% of daily goal</source>
        <translation>Օրական սահմանաքանակի %L1%</translation>
    </message>
</context>
<context>
    <name>DictionaryDialog</name>
    <message>
        <source>Set Language</source>
        <translation>Ընտրել լեզուն</translation>
    </message>
</context>
<context>
    <name>Document</name>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Անանուն %1)</translation>
    </message>
    <message>
        <source>%1 (Read-Only)</source>
        <translation>%L1% (միայն ընթերցման համար)</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Ներողություն։</translation>
    </message>
    <message>
        <source>Unable to save &apos;%1&apos;.</source>
        <translation>«%1» նիշքի պահպանումը հնարավոր չէ։</translation>
    </message>
    <message>
        <source>Save File As</source>
        <translation>Պահպանել նիշքը որպես</translation>
    </message>
    <message>
        <source>Unable to overwrite &apos;%1&apos;.</source>
        <translation>«%1» նիշքի վերագրանցումը հնարավոր չէ։</translation>
    </message>
    <message>
        <source>Rename File</source>
        <translation>Վերանվանել նիշքը</translation>
    </message>
    <message>
        <source>Unable to rename &apos;%1&apos;.</source>
        <translation>«%1» նիշքի վերանվանումը հնարավոր չէ։</translation>
    </message>
    <message>
        <source>Reload File?</source>
        <translation>Նիշքը նորի՞ց բացել։</translation>
    </message>
    <message>
        <source>Reload the file &apos;%1&apos; from disk?</source>
        <translation>«%1» նիշքը նորի՞ց բացել սկավառակից։</translation>
    </message>
    <message>
        <source>All unsaved changes will be lost.</source>
        <translation>Չպահպանված բոլոր փոփոխությունները կկորչեն։</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Նորից բացել</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Անանուն %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Հարց</translation>
    </message>
    <message>
        <source>Saving as plain text will discard all formatting. Discard formatting?</source>
        <translation>Հասարակ տեքստի ձևաչափով պահպանումը կվերացնի ձևավորումը։ Վերացնե՞լ ձևավորումը։</translation>
    </message>
</context>
<context>
    <name>DocumentWatcher</name>
    <message>
        <source>File Changed</source>
        <translation>Նիշքը փոփոխված է։</translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; was changed by another program.</source>
        <translation>«%1» նիշքը մեկ այլ ծրագրով փոփոխվել է։</translation>
    </message>
    <message>
        <source>Do you want to reload the file?</source>
        <translation>Նիշքը նորի՞ց բացել։</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Նորից բացել</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Անտեսել</translation>
    </message>
    <message>
        <source>File Deleted</source>
        <translation>Նիշքը ջնջված է։</translation>
    </message>
    <message>
        <source>The file %1 was deleted by another program.</source>
        <translation>%1 նիշքը մեկ այլ ծրագրով ջնջվել է։</translation>
    </message>
    <message>
        <source>Do you want to save or close the file?</source>
        <translation>Նիշքը պահպանե՞լ, թե փակել։</translation>
    </message>
</context>
<context>
    <name>DocxReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>Սեղմված նիշքը բացել հնարավոր չէ։</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <source>Search for:</source>
        <translation>Փնտրել</translation>
    </message>
    <message>
        <source>Replace with:</source>
        <translation>Փոխարինել հետևյալով՝</translation>
    </message>
    <message>
        <source>Ignore case</source>
        <translation>Մեծատառ թե փոքրատառ՝ կարևոր չէ։</translation>
    </message>
    <message>
        <source>Whole words only</source>
        <translation>Միայն ամբողջական բառեր</translation>
    </message>
    <message>
        <source>Regular expressions</source>
        <translation>Կանոնավոր արտահայտություններ</translation>
    </message>
    <message>
        <source>Search up</source>
        <translation>Փնտրել վերևում</translation>
    </message>
    <message>
        <source>Search down</source>
        <translation>Փնտրել ներքևում</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>Գ&amp;տնել</translation>
    </message>
    <message>
        <source>&amp;Replace</source>
        <translation>&amp;Փոխարինել</translation>
    </message>
    <message>
        <source>Replace &amp;All</source>
        <translation>Փոխարինել &amp;բոլորը</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Գտնել</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Փոխարինել</translation>
    </message>
    <message numerus="yes">
        <source>Replace %n instance(s)?</source>
        <translation>
            <numerusform>Փոխարինե՞լ %n համընկումը։</numerusform>
            <numerusform>Փոխարինե՞լ %n համընկումը։</numerusform>
        </translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Հարց</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Ներողություն։</translation>
    </message>
    <message>
        <source>Phrase not found.</source>
        <translation>Փնտրվածը չի գտնվել։</translation>
    </message>
</context>
<context>
    <name>FormatManager</name>
    <message>
        <source>OpenDocument Text</source>
        <translation>OpenDocument Text</translation>
    </message>
    <message>
        <source>Office Open XML</source>
        <translation>Office Open XML</translation>
    </message>
    <message>
        <source>Rich Text Format</source>
        <translation>Rich Text Format</translation>
    </message>
    <message>
        <source>Plain Text</source>
        <translation>Հասարակ տեքստ</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation>Բոլոր նիշքերը</translation>
    </message>
    <message>
        <source>All Supported Files</source>
        <translation>Ծրագրին համապատասխանող բոլոր նիշքերը</translation>
    </message>
    <message>
        <source>OpenDocument Flat XML</source>
        <translation>OpenDocument Flat XML</translation>
    </message>
</context>
<context>
    <name>Highlighter</name>
    <message>
        <source>Add</source>
        <translation>Ավելացնել</translation>
    </message>
    <message>
        <source>Check Spelling...</source>
        <translation>Ստուգել ուղղագրությունը...</translation>
    </message>
    <message>
        <source>(No suggestions found)</source>
        <translation>(Տարբերակներ չկան)</translation>
    </message>
</context>
<context>
    <name>ImageButton</name>
    <message>
        <source>Open Image</source>
        <translation>Բացել նկարը</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Նկարներ</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Ընտրել ծրագրի լեզուն</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Համակարգի լեզուն&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Նշում</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Լեզվի փոփոխության կայացման համար ծրագիրը վերագործարկել</translation>
    </message>
</context>
<context>
    <name>OdtReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>Սեղմված նիշքը բացել հնարավոր չէ։</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Նախընտրանքներ</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Ընդհանուր</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Վիճակագրություն</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Գործիքագոտի</translation>
    </message>
    <message>
        <source>Spell Checking</source>
        <translation>Ուղղագրության ստուգում</translation>
    </message>
    <message>
        <source>Select Dictionary</source>
        <translation>Ընտրել բառարան</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Ներողություն։</translation>
    </message>
    <message>
        <source>Unable to open archive.</source>
        <translation>Սեղմված նիշքը բացել հնարավոր չէ։</translation>
    </message>
    <message>
        <source>The archive does not contain a usable dictionary.</source>
        <translation>Սեղմված նիշքում գործածելի բառարան չկա։</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Հարց</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Ստեղների համադրություններ</translation>
    </message>
    <message>
        <source>One or more shortcuts conflict. Do you wish to proceed?</source>
        <translation>Մեկ կամ մի քանի համադրություն համընկնում է։ Շարունակե՞լ։</translation>
    </message>
    <message>
        <source>The dictionary &quot;%1&quot; already exists. Do you want to replace it?</source>
        <translation>&quot;%1&quot; բառարանն արդեն կա։ Փոխարինել այն նորո՞վ։</translation>
    </message>
    <message>
        <source>Daily Goal</source>
        <translation>Օրական սահմանաքանակ</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Չիք</translation>
    </message>
    <message>
        <source>Minutes:</source>
        <translation>Րոպեներ</translation>
    </message>
    <message>
        <source>Words:</source>
        <translation>Բառեր</translation>
    </message>
    <message>
        <source>Editing</source>
        <translation>Խմբագրում</translation>
    </message>
    <message>
        <source>Always vertically center</source>
        <translation>Միշտ կենտրոնում՝ ըստ ուղղահայացի</translation>
    </message>
    <message>
        <source>Block insertion cursor</source>
        <translation>Ներմուծման ուղղանկյուն շարժագիծ</translation>
    </message>
    <message>
        <source>Smooth fonts</source>
        <translation>Տառատեսակը հարթեցնել</translation>
    </message>
    <message>
        <source>Typewriter sounds</source>
        <translation>Գրամեքենայի ձայն</translation>
    </message>
    <message>
        <source>Smart quotes:</source>
        <translation>Չակերտները փոխել</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Երկգծիկ</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Միագծիկ</translation>
    </message>
    <message>
        <source>Scenes</source>
        <translation>Դրվագներ</translation>
    </message>
    <message>
        <source>Divider:</source>
        <translation>Բաժանիչ նշան</translation>
    </message>
    <message>
        <source>Saving</source>
        <translation>Պահպանում</translation>
    </message>
    <message>
        <source>Remember cursor position</source>
        <translation>Հիշել շարժագծի դիրքը</translation>
    </message>
    <message>
        <source>Word count</source>
        <translation>Բառերի քանակ</translation>
    </message>
    <message>
        <source>Page count</source>
        <translation>Էջերի քանակ</translation>
    </message>
    <message>
        <source>Paragraph count</source>
        <translation>Պարբերությունների քանակ</translation>
    </message>
    <message>
        <source>Character count</source>
        <translation>Նիշերի քանակ</translation>
    </message>
    <message>
        <source>Characters:</source>
        <translation>Նիշեր</translation>
    </message>
    <message>
        <source>Paragraphs:</source>
        <translation>Պարբերություններ</translation>
    </message>
    <message>
        <source>Word Count Algorithm</source>
        <translation>Բառաքանակի հաշվարկի քայլաշար</translation>
    </message>
    <message>
        <source>Reset daily progress for today to zero?</source>
        <translation>Օրական սահմանաքանակի այսօրվա բաժինը զրոյացնե՞լ։</translation>
    </message>
    <message>
        <source>Write byte order mark in plain text files</source>
        <translation>Հասարակ տեքստային նիշքերում գրել բայտերի կարգանիշը</translation>
    </message>
    <message>
        <source>Default format:</source>
        <translation>Լռելյայն ձևաչափ</translation>
    </message>
    <message>
        <source>Reset Today</source>
        <translation>Վերականգնել այսօր</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Պատմություն</translation>
    </message>
    <message>
        <source>Remember history</source>
        <translation>Հիշել պատմությունը</translation>
    </message>
    <message>
        <source>Show streaks</source>
        <translation>Ցույց տալ շերտերը</translation>
    </message>
    <message>
        <source>Minimum progress for streaks:</source>
        <translation>Շերտերի նվազագույն առաջընթաց</translation>
    </message>
    <message>
        <source>Detect word boundaries</source>
        <translation>Հաշվել բառերի սահմանները</translation>
    </message>
    <message>
        <source>Divide character count by six</source>
        <translation>Նիշերի քանակը բաժանել վեցի</translation>
    </message>
    <message>
        <source>Count each letter as a word</source>
        <translation>Ամեն տառ հաշվել որպես բառ</translation>
    </message>
    <message>
        <source>Page Count Algorithm</source>
        <translation>Էջահաշվարկի քայլաշար</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Ոճ</translation>
    </message>
    <message>
        <source>Icons Only</source>
        <translation>Միայն պատկերակներ</translation>
    </message>
    <message>
        <source>Text Only</source>
        <translation>Միայն տեքստ</translation>
    </message>
    <message>
        <source>Text Alongside Icons</source>
        <translation>Տեքստ՝ պատկերակների կողքին</translation>
    </message>
    <message>
        <source>Text Under Icons</source>
        <translation>Տեքստ՝ պատկերակների տակ</translation>
    </message>
    <message>
        <source>Text Position:</source>
        <translation>Տեքստի դիրք</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Գործողություններ</translation>
    </message>
    <message>
        <source>Move Up</source>
        <translation>Տանել վերև</translation>
    </message>
    <message>
        <source>Move Down</source>
        <translation>Տանել ներքև</translation>
    </message>
    <message>
        <source>Add Separator</source>
        <translation>Դնել բաժանագիծ</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Հրաման</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation>Ստեղների համադրություն</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Գործողություն</translation>
    </message>
    <message>
        <source>Check spelling as you type</source>
        <translation>Ուղղագրությունը ստուգել մուտքագրմանը զուգընթաց</translation>
    </message>
    <message>
        <source>Ignore words in UPPERCASE</source>
        <translation>Անտեսել ՄԵԾԱՏԱՌԵՐՈՎ բառերը</translation>
    </message>
    <message>
        <source>Ignore words with numbers</source>
        <translation>Անտեսել թվանշաններով բառերը</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Լեզու</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Ավելացնել</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Հեռացնել</translation>
    </message>
    <message>
        <source>Personal Dictionary</source>
        <translation>Անձնական բառարան</translation>
    </message>
    <message>
        <source>Remove current dictionary?</source>
        <translation>Հեռացնե՞լ այս բառարանը</translation>
    </message>
    <message>
        <source>User Interface</source>
        <translation>Օգտվողի միջերես</translation>
    </message>
    <message>
        <source>Always show scrollbar</source>
        <translation>Միշտ ցույց տալ ոլորագոտին</translation>
    </message>
    <message>
        <source>Always show top bar</source>
        <translation>Միշտ ցույց տալ վերին գոտին</translation>
    </message>
    <message>
        <source>Always show bottom bar</source>
        <translation>Միշտ ցույց տալ ստորին գոտին</translation>
    </message>
</context>
<context>
    <name>RtfReader</name>
    <message>
        <source>Not a supported RTF file.</source>
        <translation>Անհամապատասխան RTF նիշք</translation>
    </message>
</context>
<context>
    <name>RtfTokenizer</name>
    <message>
        <source>Unexpectedly reached end of file.</source>
        <translation>Անսպասելի ժամանում նիշքի վերջին։</translation>
    </message>
</context>
<context>
    <name>SceneList</name>
    <message>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl+Shift+վարընթաց սլաք</translation>
    </message>
    <message>
        <source>Move Scenes Up</source>
        <translation>Դրվագները վերև տանել</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Shift+վերընթաց սլաք</translation>
    </message>
    <message>
        <source>Toggle Scene List</source>
        <translation>Ցույց տալ/թաքցնել դրվագացանկը</translation>
    </message>
    <message>
        <source>Shift+F4</source>
        <translation>Shift+F4</translation>
    </message>
    <message>
        <source>Show scene list (%1)</source>
        <translation>Ցույց տալ դրվագացանկը (%1)</translation>
    </message>
    <message>
        <source>Hide scene list (%1)</source>
        <translation>Թաքցնել դրվագացանկը (%1)</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Զտել</translation>
    </message>
    <message>
        <source>Move Scenes Down</source>
        <translation>Դրվագները ներքև տանել</translation>
    </message>
    <message>
        <source>Resize scene list</source>
        <translation>Դրվագացանկի չափը փոխել</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message>
        <source>Default</source>
        <translation>Լռելյայն</translation>
    </message>
</context>
<context>
    <name>SessionManager</name>
    <message>
        <source>Manage Sessions</source>
        <translation>Գործաժամերի կառավարում</translation>
    </message>
    <message>
        <source>S&amp;essions</source>
        <translation>&amp;Գործաժամեր</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Նոր</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Կրկնօրինակել</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Վերանվանել</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ջնջել</translation>
    </message>
    <message>
        <source>Switch To</source>
        <translation>Փոխադրվել</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Նոր գործաժամ</translation>
    </message>
    <message>
        <source>Duplicate Session</source>
        <translation>Կրկնօրինակել գործաժամը</translation>
    </message>
    <message>
        <source>Rename Session</source>
        <translation>Վերանվանել գործաժամը</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Հարց</translation>
    </message>
    <message>
        <source>Delete selected session?</source>
        <translation>Ջնջե՞լ ընտրված գործաժամը։</translation>
    </message>
    <message>
        <source>Session name:</source>
        <translation>Գործաժամի անվանում</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Ներողություն։</translation>
    </message>
    <message>
        <source>The requested session name is already in use.</source>
        <translation>Գործաժամի այդ անունն արդեն գործածվում է։</translation>
    </message>
    <message>
        <source>&amp;New...</source>
        <translation>Ն&amp;որ...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>&amp;Manage...</source>
        <translation>&amp;Կառավարում...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+M</source>
        <translation>Ctrl+Shift+M</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <source>Clear</source>
        <translation>Մաքրել</translation>
    </message>
    <message>
        <source>Reset to Default</source>
        <translation>Վերականգնել լռելյայն կարգավորումը</translation>
    </message>
    <message>
        <source>Shortcut:</source>
        <translation>Ստեղների համադրություն</translation>
    </message>
</context>
<context>
    <name>SmartQuote</name>
    <message>
        <source>Replacing quotation marks...</source>
        <translation>Չակերտների փոփոխում...</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Խնդրում ենք սպասել</translation>
    </message>
</context>
<context>
    <name>SpellChecker</name>
    <message>
        <source>Check Spelling</source>
        <translation>Ստուգել ուղղագրությունը</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Ավելացնել</translation>
    </message>
    <message>
        <source>&amp;Ignore</source>
        <translation>Անտեսել</translation>
    </message>
    <message>
        <source>I&amp;gnore All</source>
        <translation>Ան&amp;տեսել ամբողջը</translation>
    </message>
    <message>
        <source>&amp;Change</source>
        <translation>&amp;Փոխել</translation>
    </message>
    <message>
        <source>C&amp;hange All</source>
        <translation>Փո&amp;խել ամբողջը</translation>
    </message>
    <message>
        <source>Not in dictionary:</source>
        <translation>Բառարանում բացակայում է՝</translation>
    </message>
    <message>
        <source>Change to:</source>
        <translation>Փոխարինել հետևյալով՝</translation>
    </message>
    <message>
        <source>Checking spelling...</source>
        <translation>Ուղղագրության ստուգում...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Չեղարկել</translation>
    </message>
    <message>
        <source>Please wait</source>
        <translation>Խնդրում ենք սպասել</translation>
    </message>
    <message>
        <source>Continue checking at beginning of file?</source>
        <translation>Շարունակե՞լ ստուգումը նիշքի սկզբում։</translation>
    </message>
    <message>
        <source>Spell check complete.</source>
        <translation>Ուղղագրության ստուգումն ավարտված է։</translation>
    </message>
</context>
<context>
    <name>SymbolsDialog</name>
    <message>
        <source>Symbols</source>
        <translation>Նշաններ</translation>
    </message>
    <message>
        <source>Recently used symbols</source>
        <translation>Վերջերս գործածված նշաններ</translation>
    </message>
    <message>
        <source>All symbols</source>
        <translation>Բոլոր նշանները</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Մանրամասներ</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Անվանում</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>Ներմուծել</translation>
    </message>
</context>
<context>
    <name>SymbolsModel</name>
    <message>
        <source>Blocks</source>
        <translation>Բլոկներ</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>Գրանշաններ</translation>
    </message>
</context>
<context>
    <name>Theme</name>
    <message>
        <source>Untitled %1</source>
        <translation>Անանուն %1</translation>
    </message>
</context>
<context>
    <name>ThemeDialog</name>
    <message>
        <source>Name:</source>
        <translation>Անվանում</translation>
    </message>
    <message>
        <source>No Image</source>
        <translation>Նկար պետք չէ</translation>
    </message>
    <message>
        <source>Tiled</source>
        <translation>Սալապատված</translation>
    </message>
    <message>
        <source>Centered</source>
        <translation>Կենտրոնում տեղադրված</translation>
    </message>
    <message>
        <source>Stretched</source>
        <translation>Լայնքով ձգված</translation>
    </message>
    <message>
        <source>Scaled</source>
        <translation>Համաչափորեն տարածված</translation>
    </message>
    <message>
        <source>Zoomed</source>
        <translation>Խոշորացված</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation>Անթափանցություն՝</translation>
    </message>
    <message>
        <source>Position:</source>
        <translation>Դիրք՝</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Լայնք՝</translation>
    </message>
    <message>
        <source>Round Text Background Corners</source>
        <translation>Տեքստի խորքի անկյունները կլորացնել</translation>
    </message>
    <message>
        <source>Radius:</source>
        <translation>Շառավիղ՝</translation>
    </message>
    <message>
        <source>Blur Text Background</source>
        <translation>Տեքստի խորքն աղոտացնել</translation>
    </message>
    <message>
        <source>Text Background Drop Shadow</source>
        <translation>Տեքստի խորքի ստվերանկում</translation>
    </message>
    <message>
        <source>Vertical Offset:</source>
        <translation>Ուղղահայաց շեղում՝</translation>
    </message>
    <message>
        <source>Margins</source>
        <translation>Լուսանցքներ</translation>
    </message>
    <message>
        <source>Window:</source>
        <translation>Պատուհան՝</translation>
    </message>
    <message>
        <source>Page:</source>
        <translation>Էջ՝</translation>
    </message>
    <message>
        <source>Indent first line</source>
        <translation>Առաջին տողագլուխը՝ ներքաշված</translation>
    </message>
    <message>
        <source>Above:</source>
        <translation>Վերևից՝</translation>
    </message>
    <message>
        <source>Below:</source>
        <translation>Ներքևից՝</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Հեռացնել</translation>
    </message>
    <message>
        <source>Edit Theme</source>
        <translation>Թեմայի խմբագրում</translation>
    </message>
    <message>
        <source>Window Background</source>
        <translation>Պատուհանի խորք</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Տեսակ</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Գույն</translation>
    </message>
    <message>
        <source>Image:</source>
        <translation>Նկար</translation>
    </message>
    <message>
        <source> pixels</source>
        <translation>պիքսել</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Ձախից</translation>
    </message>
    <message>
        <source>Text Background</source>
        <translation>Տեքստի խորք</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Աջից</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Տեքստ</translation>
    </message>
    <message>
        <source>Font:</source>
        <translation>Տառատեսակ</translation>
    </message>
    <message>
        <source>Misspelled:</source>
        <translation>Սխալագիր բառեր</translation>
    </message>
    <message>
        <source>Line Spacing</source>
        <translation>Միջտողային տարածություն</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Մեկ տողաչափով</translation>
    </message>
    <message>
        <source>1.5 Lines</source>
        <translation>1.5 տողաչափով</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Կրկնակի տողաչափով</translation>
    </message>
    <message>
        <source>Proportional</source>
        <translation>Համամասնական</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Բարձրություն</translation>
    </message>
    <message>
        <source>Paragraph Spacing</source>
        <translation>Պարբերության տարածություն</translation>
    </message>
    <message>
        <source>Tab Width:</source>
        <translation>Սյունատի լայնք</translation>
    </message>
    <message>
        <source>New Theme</source>
        <translation>Նոր թեմա</translation>
    </message>
</context>
<context>
    <name>ThemeManager</name>
    <message>
        <source>Themes</source>
        <translation>Թեմաներ</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Լռելյայն</translation>
    </message>
    <message>
        <source>Gentle Blues</source>
        <translation>Մեղմ բլյուզ</translation>
    </message>
    <message>
        <source>Old School</source>
        <translation>Հին դպրոց</translation>
    </message>
    <message>
        <source>Space Dreams</source>
        <translation>Տիեզերական երազներ</translation>
    </message>
    <message>
        <source>Writing Desk</source>
        <translation>Գրասեղան</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Նոր</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Կրկնօրինակել</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Ուրիշ</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Խմբագրել</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ջնջել</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Ներմուծել</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Արտահանել</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Հարց</translation>
    </message>
    <message>
        <source>Delete theme &apos;%1&apos;?</source>
        <translation>Ջնջե՞լ «%1» թեման։</translation>
    </message>
    <message>
        <source>Themes (%1)</source>
        <translation>Թեմաներ (%1)</translation>
    </message>
    <message>
        <source>Import Theme</source>
        <translation>Ներմուծել թեմա</translation>
    </message>
    <message>
        <source>Export Theme</source>
        <translation>Թեման արտահանել</translation>
    </message>
    <message>
        <source>Bitter Skies</source>
        <translation>Մռայլ երկինք</translation>
    </message>
    <message>
        <source>Enchantment</source>
        <translation>Դյութանք</translation>
    </message>
    <message>
        <source>Spy Games</source>
        <translation>Լրտեսական խաղեր</translation>
    </message>
    <message>
        <source>Tranquility</source>
        <translation>Հանդարտություն</translation>
    </message>
</context>
<context>
    <name>Timer</name>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; - %2</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; - %2</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Հարց</translation>
    </message>
    <message>
        <source>Delete timer?</source>
        <translation>Ջնջե՞լ ժամաչափիչը։</translation>
    </message>
    <message>
        <source>&lt;b&gt;Words:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Բառեր&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pages:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Էջեր&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Paragraphs:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Պարբերություններ&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Characters:&lt;/b&gt; %L1 / %L2</source>
        <translation>&lt;b&gt;Նիշեր&lt;/b&gt; %L1 / %L2</translation>
    </message>
    <message>
        <source>Set Delay</source>
        <translation>Ընդմիջում</translation>
    </message>
    <message>
        <source>Set Time</source>
        <translation>Ժամանակամիջոց</translation>
    </message>
    <message>
        <source>Delay:</source>
        <translation>Ընդմիջում</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>Ժամանակ</translation>
    </message>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>Alarm</source>
        <translation>Զարթուցիչ</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Տեսակ</translation>
    </message>
    <message>
        <source>Memo:</source>
        <translation>Հաղորդագրություն</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Խմբագրել</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ջնջել</translation>
    </message>
</context>
<context>
    <name>TimerDisplay</name>
    <message>
        <source>HH:mm:ss</source>
        <translation>ԺԺ:րր:վվ</translation>
    </message>
    <message>
        <source>No timers running</source>
        <translation>Միացված ժամաչափիչ չկա։</translation>
    </message>
</context>
<context>
    <name>TimerManager</name>
    <message>
        <source>Timers</source>
        <translation>Ժամաչափիչներ</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Նոր</translation>
    </message>
    <message>
        <source>Recent</source>
        <translation>Վերջերս գործածված</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Հարց</translation>
    </message>
    <message>
        <source>Cancel editing timers?</source>
        <translation>Չեղարկե՞լ ժամաչափիչների խմբագրումը։</translation>
    </message>
    <message>
        <source>+HH:mm:ss</source>
        <translation>+ԺԺ:րր:վվ</translation>
    </message>
    <message>
        <source>%1 - %2</source>
        <translation>%1 - %2</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Loading themes</source>
        <translation>Թեմաների բեռնում</translation>
    </message>
    <message>
        <source>Loading sounds</source>
        <translation>Ձայնային նիշքերի բեռնում</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Անանուն</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Բացել նիշքը</translation>
    </message>
    <message>
        <source>About FocusWriter</source>
        <translation>FocusWriter-ի մասին</translation>
    </message>
    <message>
        <source>FocusWriter</source>
        <translation>FocusWriter</translation>
    </message>
    <message>
        <source>A simple fullscreen word processor</source>
        <translation>Լիէկրան պարզ տեքստային խմբագրիչ</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Պատճենաշնորհ &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Թողարկված է &lt;a href=%1&gt;GPL 3&lt;/a&gt;-ի արտոնագրով։</translation>
    </message>
    <message>
        <source>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</source>
        <translation>Գործածված են &lt;a href=%1&gt;Oxygen&lt;/a&gt; թեմայի պատկերակները։</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Պատկերակները գործածված են &lt;a href=%1&gt;LGPL 3&lt;/a&gt;-ի արտոնագրով։</translation>
    </message>
    <message>
        <source>Characters: %L1 / %L2</source>
        <translation>Նիշեր՝ %L1 / %L2</translation>
    </message>
    <message>
        <source>Pages: %L1</source>
        <translation>Էջեր՝ %L1</translation>
    </message>
    <message>
        <source>Paragraphs: %L1</source>
        <translation>Պարբերություններ՝ %L1</translation>
    </message>
    <message>
        <source>Words: %L1</source>
        <translation>Բառեր՝ %L1</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Բացվում է %1-ը</translation>
    </message>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Անանուն %1)</translation>
    </message>
    <message>
        <source>List all documents</source>
        <translation>Բոլոր փաստաթղթերը</translation>
    </message>
    <message>
        <source>Switch to Next Document</source>
        <translation>Անցնել հաջորդ փաստաթղթին</translation>
    </message>
    <message>
        <source>Switch to Previous Document</source>
        <translation>Անցնել նախորդ փաստաթղթին</translation>
    </message>
    <message>
        <source>Switch to First Document</source>
        <translation>Անցնել առաջին փաստաթղթին</translation>
    </message>
    <message>
        <source>Switch to Last Document</source>
        <translation>Անցնել վերջին փաստաթղթին</translation>
    </message>
    <message>
        <source>Switch to Document %1</source>
        <translation>Անցնել %1 փաստաթղթին </translation>
    </message>
    <message>
        <source>Loading settings</source>
        <translation>Կարգավորումները բեռնվում են</translation>
    </message>
    <message>
        <source>Emergency cache is not writable.</source>
        <translation>Պահեստային հիշողությունը գրանցման ենթակա չէ։</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Զգուշացում</translation>
    </message>
    <message>
        <source>FocusWriter was not shut down cleanly.</source>
        <translation>FocusWriter-ը ճիշտ չէր փակվել։</translation>
    </message>
    <message>
        <source>Restore from the emergency cache?</source>
        <translation>Վերականգնե՞լ պահեստային հիշողությունից։</translation>
    </message>
    <message>
        <source>Some files could not be opened.</source>
        <translation>Որոշ նիշքեր հնարավոր չեղավ բացել։</translation>
    </message>
    <message>
        <source>Some files were opened Read-Only.</source>
        <translation>Որոշ նիշքեր բացվել են միայն ընթերցման համար։</translation>
    </message>
    <message>
        <source>&apos;%1&apos; is newer than the cached copy.</source>
        <translation>«%1» նիշքը պահեստային օրինակից նոր է։</translation>
    </message>
    <message>
        <source>Overwrite newer file?</source>
        <translation>Նոր տարբերակը պահեստայինո՞վ փոխարինել։</translation>
    </message>
    <message>
        <source>Save Changes?</source>
        <translation>Պահպանե՞լ փոփոխությունները։</translation>
    </message>
    <message>
        <source>Save changes to the file &apos;%1&apos; before closing?</source>
        <translation>Փակելուց առաջ «%1» նիշքի փոփոխությունները պահպանե՞լ։</translation>
    </message>
    <message>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translation>Փոփոխությունները կկորչեն, եթե դրանք չպահպանեք։</translation>
    </message>
    <message>
        <source>Unable to load typewriter sounds.</source>
        <translation>Հնարավոր չեղավ գրամեքենայի ձայնը բեռնել։</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Նիշք</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>Ն&amp;որ</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>&amp;Բացել...</translation>
    </message>
    <message>
        <source>Reloa&amp;d</source>
        <translation>Նոր&amp;ից բացել</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>Պահպանել</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>&amp;Պահպանել որպես</translation>
    </message>
    <message>
        <source>&amp;Rename...</source>
        <translation>&amp;Վերանվանել...</translation>
    </message>
    <message>
        <source>Save A&amp;ll</source>
        <translation>Պա&amp;հպանել բոլորը</translation>
    </message>
    <message>
        <source>Manage Sessions</source>
        <translation>Կա&amp;ռավարել գործաժամերը</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Նոր գո&amp;րծաժամ</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>&amp;Տպել...</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Փակել</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Դուրս գալ</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Խմբագրում</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Չեղարկել</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>&amp;Կրկնել</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>Կ&amp;տրել</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Պատճենել</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>&amp;Փակցնել</translation>
    </message>
    <message>
        <source>Paste &amp;Unformatted</source>
        <translation>Փակցնել &amp;առանց ձևավորման</translation>
    </message>
    <message>
        <source>Ctrl+Shift+V</source>
        <translation>Ctrl+Shift+V</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation>&amp;Ընտրել ամբողջը</translation>
    </message>
    <message>
        <source>Select &amp;Scene</source>
        <translation>Ընտրել &amp;դրվագ</translation>
    </message>
    <message>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Shift+A</translation>
    </message>
    <message>
        <source>Fo&amp;rmat</source>
        <translation>Ձևավորում</translation>
    </message>
    <message>
        <source>&amp;Bold</source>
        <translation>&amp;Թավատառ</translation>
    </message>
    <message>
        <source>&amp;Italic</source>
        <translation>&amp;Շեղատառ</translation>
    </message>
    <message>
        <source>&amp;Underline</source>
        <translation>&amp;Ընդգծված</translation>
    </message>
    <message>
        <source>Stri&amp;kethrough</source>
        <translation>&amp;Ջնջագծված</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Sup&amp;erscript</source>
        <translation>&amp;Վերտողագիր</translation>
    </message>
    <message>
        <source>Ctrl+^</source>
        <translation>Ctrl+^</translation>
    </message>
    <message>
        <source>&amp;Subscript</source>
        <translation>&amp;Ենթատողագիր</translation>
    </message>
    <message>
        <source>Ctrl+_</source>
        <translation>Ctrl+_</translation>
    </message>
    <message>
        <source>Align &amp;Left</source>
        <translation>Ուղղել ձա&amp;խից</translation>
    </message>
    <message>
        <source>Ctrl+{</source>
        <translation>Ctrl+{</translation>
    </message>
    <message>
        <source>Align &amp;Center</source>
        <translation>Ուղղել &amp;կենտրոնով</translation>
    </message>
    <message>
        <source>Ctrl+|</source>
        <translation>Ctrl+|</translation>
    </message>
    <message>
        <source>Align &amp;Right</source>
        <translation>Ուղղել աջ&amp;ից</translation>
    </message>
    <message>
        <source>Ctrl+}</source>
        <translation>Ctrl+}</translation>
    </message>
    <message>
        <source>Align &amp;Justify</source>
        <translation>Երկկողմ &amp;հավասարեցում</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>&amp;Decrease Indent</source>
        <translation>&amp;Փոքրացնել տողագլխի խորքը</translation>
    </message>
    <message>
        <source>Ctrl+&lt;</source>
        <translation>Ctrl+&lt;</translation>
    </message>
    <message>
        <source>I&amp;ncrease Indent</source>
        <translation>Մե&amp;ծացնել տողագլխի խորքը</translation>
    </message>
    <message>
        <source>Ctrl+&gt;</source>
        <translation>Ctrl+&gt;</translation>
    </message>
    <message>
        <source>Le&amp;ft to Right Block</source>
        <translation>Ձախից աջ &amp;տանել</translation>
    </message>
    <message>
        <source>Ri&amp;ght to Left Block</source>
        <translation>Աջից ձախ տա&amp;նել</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>&amp;Գործիքներ</translation>
    </message>
    <message>
        <source>&amp;Find...</source>
        <translation>Գ&amp;տնել...</translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation>Գտնել &amp;հաջորդը</translation>
    </message>
    <message>
        <source>Find Pre&amp;vious</source>
        <translation>Գտնել &amp;նախորդը</translation>
    </message>
    <message>
        <source>&amp;Replace...</source>
        <translation>&amp;Փոխարինել...</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Smart &amp;Quotes</source>
        <translation>&amp;Չակերտները փոխել</translation>
    </message>
    <message>
        <source>Update &amp;Document</source>
        <translation>&amp;Թարմացնել փաստաթուղթը</translation>
    </message>
    <message>
        <source>Update &amp;Selection</source>
        <translation>Թարմացնել &amp;ընտրված հատվածը</translation>
    </message>
    <message>
        <source>&amp;Spelling...</source>
        <translation>Ու&amp;ղղագրություն...</translation>
    </message>
    <message>
        <source>F7</source>
        <translation>F7</translation>
    </message>
    <message>
        <source>Set &amp;Language...</source>
        <translation>Ընտրել &amp;լեզուն...</translation>
    </message>
    <message>
        <source>&amp;Timers...</source>
        <translation>&amp;Ժամաչափիչներ...</translation>
    </message>
    <message>
        <source>S&amp;ymbols...</source>
        <translation>Ն&amp;շաններ...</translation>
    </message>
    <message>
        <source>&amp;Daily Progress</source>
        <translation>&amp;Օրական առաջընթաց</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Կարգավորումներ</translation>
    </message>
    <message>
        <source>Show &amp;Toolbar</source>
        <translation>Ցույց տալ &amp;գործիքագոտին</translation>
    </message>
    <message>
        <source>Show &amp;Menu Icons</source>
        <translation>Ցույց տալ &amp;ընտրացանկի պատկերակները</translation>
    </message>
    <message>
        <source>F&amp;ocused Text</source>
        <translation>&amp;Տեքստային հատվածի ընդգծում</translation>
    </message>
    <message>
        <source>&amp;Fullscreen</source>
        <translation>Ամբողջ &amp;էկրանով</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <source>M&amp;inimize</source>
        <translation>&amp;Ամփոփել</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>&amp;Themes...</source>
        <translation>&amp;Թեմաներ...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>&amp;Ընտրանքներ...</translation>
    </message>
    <message>
        <source>Focus Off</source>
        <translation>Անջատված է</translation>
    </message>
    <message>
        <source>Focus One Line</source>
        <translation>Մեկ տողի ընդգծում</translation>
    </message>
    <message>
        <source>Focus Three Lines</source>
        <translation>Երեք տողի ընդգծում</translation>
    </message>
    <message>
        <source>&amp;Paragraph</source>
        <translation>&amp;Պարբերություն</translation>
    </message>
    <message>
        <source>Focus Paragraph</source>
        <translation>Պարբերության ընդգծում</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Օգնություն</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Ծրագրի &amp;լեզուն...</translation>
    </message>
    <message>
        <source>Some files were unsupported and could not be opened.</source>
        <translation>Որոշ նիշքեր ծրագրին չեն համապատասխանում և չեն կարող բացվել։</translation>
    </message>
    <message>
        <source>&amp;Off</source>
        <translation>Ան&amp;ջատված է</translation>
    </message>
    <message>
        <source>One &amp;Line</source>
        <translation>&amp;Մեկ տող</translation>
    </message>
    <message>
        <source>&amp;Three Lines</source>
        <translation>&amp;Երեք տող</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Ծրագրի մասին</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Qt-ի &amp;մասին</translation>
    </message>
    <message>
        <source>Pa&amp;ge Setup...</source>
        <translation>&amp;Էջի կարգավորում...</translation>
    </message>
    <message>
        <source>&amp;Heading</source>
        <translation>&amp;Գլխագիր</translation>
    </message>
    <message>
        <source>Heading &amp;1</source>
        <translation>Գլխագիր &amp;1</translation>
    </message>
    <message>
        <source>Heading &amp;2</source>
        <translation>Գլխագիր &amp;2</translation>
    </message>
    <message>
        <source>Heading &amp;3</source>
        <translation>Գլխագիր &amp;3</translation>
    </message>
    <message>
        <source>Heading &amp;4</source>
        <translation>Գլխագիր &amp;4</translation>
    </message>
    <message>
        <source>Heading &amp;5</source>
        <translation>Գլխագիր &amp;5</translation>
    </message>
    <message>
        <source>Heading &amp;6</source>
        <translation>Գլխագիր &amp;6</translation>
    </message>
    <message>
        <source>&amp;Normal</source>
        <translation>&amp;Սովորական</translation>
    </message>
    <message>
        <source>Update Document Smart Quotes</source>
        <translation>Ուղղել փաստաթղթի չակերտները</translation>
    </message>
    <message>
        <source>Update Selection Smart Quotes</source>
        <translation>Ուղղել ընտրված մասի չակերտները</translation>
    </message>
    <message>
        <source>Ctrl+Shift+`</source>
        <translation>Ctrl+Shift+`</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Files to open in current session.</source>
        <translation>Ներկա գործաժամում բացվելիք նիշքերը</translation>
    </message>
</context>
</TS>
